import { useState, useRef } from 'react';
import { IMaskInput } from 'react-imask';

const CentsInADollar = 100;
const DefaultTotal = 0;

function costToReadable(cost) {
  return cost / CentsInADollar;
}

function BandForm({ band }) {
  const formRef = useRef(null);
  const [total, setTotal] = useState(DefaultTotal);
  const [formIsPending, setFormIsPending] = useState(false);

  function purchase(formData) {
    console.log(formData);
    setFormIsPending(true);
  }

  function ticketQuantityChanged() {
    const formData = new FormData(formRef.current);
    const ticketQuantities = formData.getAll('ticketQuantity');

    const total = ticketQuantities.reduce((total, quantity, index) => {
      return total += (band.ticketTypes[index].cost * quantity);
    }, 0)

    setTotal(total > 0 ? total : 0)
  }

  return (
    <form className="form" action={purchase} ref={formRef}>
      <h2>Select Tickets</h2>

      {band.ticketTypes.map(({type, name, description, cost}, index) => (
        <div className="ticketWrapper" key={name}>
          <div className="ticket">
            <div className="ticketDetails">
              <h3 id={name}>{name}</h3>
              <p>{description}</p>
              <h4>${costToReadable(cost)}</h4>
            </div>
            <div>
              {/* TODO: describedby cost and description */}
              <input
                labelledby={name}
                defaultValue="0"
                name="ticketQuantity"
                id={name}
                type="number"
                step="1"
                min="0"
                onChange={ticketQuantityChanged}
              />
            </div>
          </div>
          <hr />
        </div>
      ))}

      <div className="total">
        <h3>Total</h3>
        <p aria-live="polite">${costToReadable(total)}</p>
      </div>

      <div className="information">
        <div className="form-row">
          <input
            required
            name="first_name"
            label="First Name"
            placeholder="First Name"
            type="text"
          />
          <input
            required
            name="last_name"
            label="Last Name"
            placeholder="Last Name"
            type="text"
          />
        </div>
        {/* TODO: third party library address verification */}
        <input
          required
          name="address"
          label="Address"
          placeholder="Address"
          type="text"
        />
      </div>

      <fieldset className="payment">
        <legend>Payment Details</legend>

        {/* TODO: regex pattern */}
        <IMaskInput
          required
          mask="0000 0000 0000 0000"
          name="cardNumber"
          label="Card Number"
          placeholder="0000 0000 0000 0000"
          type="text"
        ></IMaskInput>

        <div className="form-row">
          {/* TODO: regex pattern */}
          <IMaskInput
            required
            mask="00 / 00"
            pattern="\d*"
            name="cardExpiration"
            label="Card Expiration (MM/YY)"
            placeholder="MM / YY"
            type="text"
          ></IMaskInput>

          {/* TODO: regex pattern */}
          <IMaskInput
            required
            mask={Number}
            name="cardCVV"
            label="Card CVV"
            placeholder="CVV"
            type="text"
          ></IMaskInput>
        </div>
      </fieldset>

      <button type="submit" disabled={formIsPending}>Get Tickets</button>
    </form>
  );
}

export default BandForm;
